/*
 *  Database record interface for DAAP sharing
 *
 *  Copyright (C) 2008 W. Michael Petullo <mike@flyn.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

#include <libdmapsharing/daap-record.h>

static gint daap_record_init_count = 0;

static void
daap_record_init (DAAPRecordInterface *iface)
{
        daap_record_init_count++;
}

static void
daap_record_finalize (DAAPRecordInterface *iface)
{
	daap_record_init_count--;
}

/* FIXME: No G_DEFINE_INTERFACE available in GObject headers: */
GType
daap_record_get_type (void)
{
	static GType object_type = 0;
	if (!object_type) {
		static const GTypeInfo object_info = {
			sizeof(DAAPRecordInterface),
			(GBaseInitFunc) daap_record_init,
			(GBaseFinalizeFunc) daap_record_finalize
		};
		object_type =
		    g_type_register_static(G_TYPE_INTERFACE,
					   "DAAPRecord",
					   &object_info, 0);
	}
	return object_type;
}

const char *
daap_record_get_location (DAAPRecord *record)
{
	return DAAP_RECORD_GET_INTERFACE (record)->get_location (record);
}

const char *
daap_record_get_title (DAAPRecord *record)
{
	return DAAP_RECORD_GET_INTERFACE (record)->get_title (record);
}

gint32
daap_record_get_rating (DAAPRecord *record)
{
	return DAAP_RECORD_GET_INTERFACE (record)->get_rating (record);
}

gint32
daap_record_get_filesize (DAAPRecord *record)
{
	return DAAP_RECORD_GET_INTERFACE (record)->get_filesize (record);
}

const char *
daap_record_get_album (DAAPRecord *record)
{
	return DAAP_RECORD_GET_INTERFACE (record)->get_album (record);
}

const char *
daap_record_get_artist (DAAPRecord *record)
{
	return DAAP_RECORD_GET_INTERFACE (record)->get_artist (record);
}

const char *
daap_record_get_genre (DAAPRecord *record)
{
	return DAAP_RECORD_GET_INTERFACE (record)->get_genre (record);
}

const char *
daap_record_get_format (DAAPRecord *record)
{
	return DAAP_RECORD_GET_INTERFACE (record)->get_format (record);
}

gint32
daap_record_get_duration (DAAPRecord *record)
{
	return DAAP_RECORD_GET_INTERFACE (record)->get_duration (record);
}

gint32
daap_record_get_track (DAAPRecord *record)
{
	return DAAP_RECORD_GET_INTERFACE (record)->get_track (record);
}

gint32
daap_record_get_year (DAAPRecord *record)
{
	return DAAP_RECORD_GET_INTERFACE (record)->get_year (record);
}

gint32
daap_record_get_firstseen (DAAPRecord *record)
{
	return DAAP_RECORD_GET_INTERFACE (record)->get_firstseen (record);
}

gint32
daap_record_get_mtime (DAAPRecord *record)
{
	return DAAP_RECORD_GET_INTERFACE (record)->get_mtime (record);
}

gint32
daap_record_get_disc (DAAPRecord *record)
{
	return DAAP_RECORD_GET_INTERFACE (record)->get_disc (record);
}

gulong
daap_record_get_bitrate (DAAPRecord *record)
{
	return DAAP_RECORD_GET_INTERFACE (record)->get_bitrate (record);
}

gint8
daap_record_has_video (DAAPRecord *record)
{
	return DAAP_RECORD_GET_INTERFACE (record)->has_video (record);
}

GInputStream *
daap_record_read (DAAPRecord *record, GError **err)
{
	return DAAP_RECORD_GET_INTERFACE (record)->read (record, err);
}
