/*
 *  Database record interface for DMAP containers
 *
 *  Copyright (C) 2008 W. Michael Petullo <mike@flyn.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

#include <libdmapsharing/dmap-container-record.h>

static gint dmap_container_record_init_count = 0;

static void
dmap_container_record_init (DMAPContainerRecordInterface *iface)
{
        dmap_container_record_init_count++;
}

static void
dmap_container_record_finalize (DMAPContainerRecordInterface *iface)
{
	dmap_container_record_init_count--;
}

/* FIXME: No G_DEFINE_INTERFACE available in GObject headers: */
GType
dmap_container_record_get_type (void)
{
	static GType object_type = 0;
	if (!object_type) {
		static const GTypeInfo object_info = {
			sizeof(DMAPContainerRecordInterface),
			(GBaseInitFunc) dmap_container_record_init,
			(GBaseFinalizeFunc) dmap_container_record_finalize
		};
		object_type =
		    g_type_register_static(G_TYPE_INTERFACE,
					   "DMAPContainerRecord",
					   &object_info, 0);
	}
	return object_type;
}

gint
dmap_container_record_get_id (DMAPContainerRecord *record)
{
	return DMAP_CONTAINER_RECORD_GET_INTERFACE (record)->get_id (record);
}

const char *
dmap_container_record_get_name (DMAPContainerRecord *record)
{
	return DMAP_CONTAINER_RECORD_GET_INTERFACE (record)->get_name (record);
}
void
dmap_container_record_add_entry (DMAPContainerRecord *record,
				 DMAPContainerEntry *entry)
{
	return DMAP_CONTAINER_RECORD_GET_INTERFACE (record)->add_entry (record, entry);
}

guint64
dmap_container_record_get_entry_count (DMAPContainerRecord *record)
{
	return DMAP_CONTAINER_RECORD_GET_INTERFACE (record)->get_entry_count (record);
}

DMAPDb *
dmap_container_record_get_entries (DMAPContainerRecord *record,
				   DMAPDb *db)
{
	return DMAP_CONTAINER_RECORD_GET_INTERFACE (record)->get_entries (record, db);
}
