/*
 * Copyright (C) 2004,2005 Charles Schmidt <cschmidt2@emich.edu>
 * Copyright (C) 2006 INDT
 *  Andre Moreira Magalhaes <andre.magalhaes@indt.org.br>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA*
 */

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#include "dpap-connection.h"
#include "dpap-root-item.h"
#include "dmap-structure.h"

#include <string.h>

#include <libsoup/soup.h>

#define DPAP_USER_AGENT "iPhoto/4.01 (Macintosh; PPC)"

static SoupMessage *dpap_connection_build_message (DMAPConnection *self,
                                                   SoupURI *base_uri,
                                                   const gchar *path,
                                                   gboolean need_hash,
                                                   gdouble version,
                                                   gint req_id);
static DMAPItem *dpap_connection_create_root_item (DMAPConnection *self);

G_DEFINE_TYPE (DPAPConnection, dpap_connection, TYPE_DMAP_CONNECTION)

static void
dpap_connection_class_init (DPAPConnectionClass *klass)
{
    DMAPConnectionClass *dmap_connection_class = (DMAPConnectionClass *) klass;

    dmap_connection_class->build_message = dpap_connection_build_message;
    dmap_connection_class->create_root_item = dpap_connection_create_root_item;
}

static void
dpap_connection_init (DPAPConnection *self)
{
}

DPAPConnection *
dpap_connection_new (const gchar *name,
                     const gchar *host,
                     gint port,
                     const gchar *password)
{
    DPAPConnection *self = DPAP_CONNECTION (g_object_new (TYPE_DPAP_CONNECTION,
            "name", name,
            "host", host,
            "port", port,
            "need-revision-number", FALSE,
            NULL));

    if (password) {
        g_object_set (self, "password", password, NULL);
    }

    return self;
}

static SoupMessage *
dpap_connection_build_message (DMAPConnection *self,
                               SoupURI *base_uri,
                               const gchar *path,
                               gboolean need_hash,
                               gdouble version,
                               gint req_id)
{
    SoupMessage *message = NULL;
    SoupURI *uri = NULL;

    uri = soup_uri_new_with_base (base_uri, path);
    if (uri == NULL) {
        return NULL;
    }

    message = soup_message_new_from_uri (SOUP_METHOD_GET, uri);
    soup_message_set_http_version (message, SOUP_HTTP_1_1);

    soup_message_headers_append (message->request_headers, "User-Agent", DPAP_USER_AGENT);
    soup_message_headers_append (message->request_headers, "Client-DMAP-Version", "1.0");
    soup_message_headers_append (message->request_headers, "Client-DPAP-Version", "1.0");

    soup_uri_free (uri);

    return message;
}

static DMAPItem *
dpap_connection_create_root_item (DMAPConnection *self)
{
    DMAPItem *item;
    gchar *name;
    g_object_get (G_OBJECT (self),
            "name", &name, NULL);
    item = DMAP_ITEM (g_object_new (TYPE_DPAP_ROOT_ITEM,
            "connection", self,
            "id", -1,
            "name", name,
            "is-folder", TRUE,
            NULL));
    g_free (name);
    return item;
}
