/*
 *  Database record interface for DPAP sharing
 *
 *  Copyright (C) 2008 W. Michael Petullo <mike@flyn.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

#include <libdmapsharing/dmap-record.h>
#include <libdmapsharing/dpap-record.h>

static gint dpap_record_init_count = 0;

static void
dpap_record_init (DPAPRecordInterface *iface)
{
        dpap_record_init_count++;
}

static void
dpap_record_finalize (DPAPRecordInterface *iface)
{
	dpap_record_init_count--;
}

/* FIXME: No G_DEFINE_INTERFACE available in GObject headers: */
GType
dpap_record_get_type (void)
{
	static GType object_type = 0;
	if (!object_type) {
		static const GTypeInfo object_info = {
			sizeof(DPAPRecordInterface),
			(GBaseInitFunc) dpap_record_init,
			(GBaseFinalizeFunc) dpap_record_finalize
		};
		object_type =
		    g_type_register_static(G_TYPE_INTERFACE,
					   "DPAPRecord",
					   &object_info, 0);
	}
	return object_type;
}

const char *
dpap_record_get_location (DPAPRecord *record)
{
	return DPAP_RECORD_GET_INTERFACE (record)->get_location (record);
}

const char *
dpap_record_get_title (DPAPRecord *record)
{
	return DPAP_RECORD_GET_INTERFACE (record)->get_title (record);
}

const char *
dpap_record_get_aspectratio (DPAPRecord *record)
{
	return DPAP_RECORD_GET_INTERFACE (record)->get_aspectratio (record);
}

const char *
dpap_record_get_filename (DPAPRecord *record)
{
	return DPAP_RECORD_GET_INTERFACE (record)->get_filename (record);
}

gint
dpap_record_get_creationdate (DPAPRecord *record)
{
	return DPAP_RECORD_GET_INTERFACE (record)->get_creationdate (record);
}

gint
dpap_record_get_filesize (DPAPRecord *record)
{
	return DPAP_RECORD_GET_INTERFACE (record)->get_filesize (record);
}

gint
dpap_record_get_largefilesize (DPAPRecord *record)
{
	return DPAP_RECORD_GET_INTERFACE (record)->get_largefilesize (record);
}

gint
dpap_record_get_pixelheight (DPAPRecord *record)
{
	return DPAP_RECORD_GET_INTERFACE (record)->get_pixelheight (record);
}

gint
dpap_record_get_pixelwidth (DPAPRecord *record)
{
	return DPAP_RECORD_GET_INTERFACE (record)->get_pixelwidth (record);
}

gint
dpap_record_get_rating (DPAPRecord *record)
{
	return DPAP_RECORD_GET_INTERFACE (record)->get_rating (record);
}

const char *
dpap_record_get_format (DPAPRecord *record)
{
	/* iTunes does not require to this to match the datatype for the image
	 * to be displayed (set to "JPEG" and served a PNG. I think this is
	 * for display to the user only.
	 */
	return DPAP_RECORD_GET_INTERFACE (record)->get_format (record);
}

const char *
dpap_record_get_comments (DPAPRecord *record)
{
	return DPAP_RECORD_GET_INTERFACE (record)->get_comments (record);
}

unsigned char *
dpap_record_get_thumbnail (DPAPRecord *record, size_t *size)
{
	return DPAP_RECORD_GET_INTERFACE (record)->get_thumbnail (record, size);
}

GInputStream *
dpap_record_read (DPAPRecord *record, GError **err)
{
	return DPAP_RECORD_GET_INTERFACE (record)->read (record, err);
}
